Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(724)

Unified Diff: ios/chrome/browser/ui/activity_services/activity_service_controller.mm

Issue 2710923002: Rename UIActivityFindLoginActionSource to UIActivityURLSource. (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | ios/chrome/browser/ui/activity_services/activity_service_controller_unittest.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ios/chrome/browser/ui/activity_services/activity_service_controller.mm
diff --git a/ios/chrome/browser/ui/activity_services/activity_service_controller.mm b/ios/chrome/browser/ui/activity_services/activity_service_controller.mm
index 9211b1acda7ebb1ca3ad1a2913e189409e1870af..c79b96bb85510215439d3abce31036a767391b57 100644
--- a/ios/chrome/browser/ui/activity_services/activity_service_controller.mm
+++ b/ios/chrome/browser/ui/activity_services/activity_service_controller.mm
@@ -193,14 +193,13 @@
DCHECK(data.nsurl);
// In order to support find-login-action protocol, the provider object
- // UIActivityFindLoginActionSource supports both Password Management
- // App Extensions (e.g. 1Password) and also provide a public.url UTType
- // for Share Extensions (e.g. Facebook, Twitter).
- UIActivityFindLoginActionSource* loginActionProvider =
- [[UIActivityFindLoginActionSource alloc]
- initWithURL:data.nsurl
- subject:data.title
- thumbnailGenerator:data.thumbnailGenerator];
+ // UIActivityURLSource supports both Password Management App Extensions
+ // (e.g. 1Password) and also provide a public.url UTType for Share Extensions
+ // (e.g. Facebook, Twitter).
+ UIActivityURLSource* loginActionProvider =
+ [[UIActivityURLSource alloc] initWithURL:data.nsurl
+ subject:data.title
+ thumbnailGenerator:data.thumbnailGenerator];
[activityItems addObject:loginActionProvider];
UIActivityTextSource* textProvider =
« no previous file with comments | « no previous file | ios/chrome/browser/ui/activity_services/activity_service_controller_unittest.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698